<?php
/**
 * Simple Machines Forum (SMF)
 *
 * @package SMF
 * @author Simple Machines
 * @copyright 2011 Simple Machines
 * @license http://www.simplemachines.org/about/smf/license.php BSD
 *
 * @version 2.0.14
 */

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '2.0';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as opposed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status separate from topic icons? */
	$settings['separate_sticky_lock'] = true;

	/* Does this theme use the strict doctype? */
	$settings['strict_doctype'] = false;

	/* Does this theme use post previews on the message index? */
	$settings['message_index_preview'] = false;

	/* Set the following variable to true if this theme requires the optional theme strings file to be loaded. */
	$settings['require_theme_strings'] = true;

}

// The main sub template above the content.
function template_html_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Death to stylesheets. Nuke them from orbit. It's the only way to be sure.
	// Use this (with care) to stop Sources loading problematic CSS files from mods.
/*
	$remove_bundled_stylesheet = function($sheets) use ($settings, &$context)
	{
		$removed = [];
		foreach ($sheets as $sheet)
		{
			$sheet_path = file_exists($settings['theme_dir']. '/css/' . $sheet . '.css') ? 'theme_url' : (file_exists($settings['default_theme_dir']. '/css/' . $sheet . '.css') ? 'default_theme_url' : '');
			if ($sheet_path)
			{
				$header = "\n\t" . '<link rel="stylesheet" type="text/css" id="' . $sheet . '_css" href="' . $settings[$sheet_path] . '/css/' . $sheet . '.css" />';
				if (strpos($context['html_headers'], $header) !== false)
				{
					$removed[] = $sheet;
					$context['html_headers'] = str_replace($header, '', $context['html_headers']);
				}
			}
		}
		return $removed;
	};
	// Add extra stylesheet names as a comma-separated list.
	// Example: (['editor_ie', 'zomg', 'rampant_muppetry']);
	$removed = $remove_bundled_stylesheet(['editor_ie']);
*/
	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' id="direction_rtl" dir="rtl"' : '', '>
<head>';

	// The ?fin20 part of this link is just here to make sure browsers don't cache it wrongly.
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/index.css?fin20" />';

	if ($context['right_to_left'])
		echo '
		<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/rtl.css?fin20" />';

	// Split out isolated areas with extra trickeries (might make life a bit easier).
	// These two stylesheets have RTL support built in via #direction_rtl foo {x: y;}.
	if (!empty($context['current_action']) && ($context['current_action'] == 'profile'))
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/profile.css" />';

	foreach (array('mlist', 'profile', 'who') as $css_action)
		if (!empty($context['current_action']) && ($context['current_action'] == $css_action))
			echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/mlist.css" />';

	// Workaround for 2.0.x bug: default Subs.php array displays registration button when registration is disabled.
	if ($modSettings['registration_method'] == 3)
		echo '
	<style type="text/css">#button_register {display: none;}</style>';

	// For layout variants call id="direction_rtl" from the HTML tag, for full support in the one file.
	// Example CSS: .foo {position: relative; left: 1em;} #direction_rtl .foo {left: auto; right: 1em;}
	// Then files for all variants, for LTR and RTL, can be called by:
	// <link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/index_', $context['theme_variant'], '.css?fin20" />';
	// If extra specificity is required to override admin.css + editor.css, use id="variant', $context['theme_variant'], '" from body tag.
	// This should cover every conceivable sane situation. Insane situations are someone else's problem. :P

	// Here comes the JavaScript bits!
	echo '
	<script type="text/javascript" src="', $settings['theme_url'], '/scripts/script.js?fin20"></script>
	<script type="text/javascript" src="', $settings['theme_url'], '/scripts/theme.js?fin20"></script>
	<script type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_default_theme_url = "', $settings['default_theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";', $context['show_pm_popup'] ? '
		var fPmPopup = function ()
		{
			if (confirm("' . $txt['show_personal_messages'] . '"))
				window.open(smf_prepareScriptUrl(smf_scripturl) + "action=pm");
		}
		addLoadEvent(fPmPopup);' : '', '
		var ajax_notification_text = "', $txt['ajax_in_progress'], '";
		var ajax_notification_cancel_text = "', $txt['modify_cancel'], '";
	// ]]></script>';

	echo '
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title_html_safe'], '" />', !empty($context['meta_keywords']) ? '
	<meta name="keywords" content="' . $context['meta_keywords'] . '" />' : '', '
	<title>', $context['page_title_html_safe'], '</title>
	<meta name="viewport" content="width=device-width, initial-scale=1" />';

	// Please don't index these Mr Robot.
	if (!empty($context['robot_no_index']))
		echo '
	<meta name="robots" content="noindex" />';

	// Present a canonical url for search engines to prevent duplicate content in their indices.
	if (!empty($context['canonical_url']))
		echo '
	<link rel="canonical" href="', $context['canonical_url'], '" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" />
	<link rel="search" href="', $scripturl, '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']) && (!empty($modSettings['allow_guestAccess']) || $context['user']['is_logged']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name_html_safe'], ' - ', $txt['rss'], '" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['links']['next']))
		echo '
	<link rel="next" href="', $context['links']['next'], '" />';
	else if (!empty($context['current_topic']))
		echo '
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';
	if (!empty($context['links']['prev']))
		echo '
	<link rel="prev" href="', $context['links']['prev'], '" />';
	else if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="', $scripturl, '?board=', $context['current_board'], '.0" />';

	// Output any remaining HTML headers (from mods, maybe?).
	echo $context['html_headers'];

	// Allow setting body tag class by action or board.
	$body_class = array();
	if (!empty($context['current_action']))
		$body_class[] = 'action_'. $context['current_action'];
	elseif (!empty($context['current_topic']))
		$body_class[] = 'action_display';
//	elseif (!empty($context['current_board']))
//		$body_class[] = 'board_'. $context['current_board'];
//	elseif (!empty($context['current_topic']))
//		$body_class[] = 'topic_'. $context['current_topic'];
	if (!empty($context['max_menu_id']))
		$body_class[] = 'area_' . $context['menu_data_' . $context['max_menu_id']]['current_area'];
	if (!empty($context['current_subaction']))
		$body_class[] = 'subaction_' . $context['current_subaction'];
	if (empty($body_class))
		$body_class[] = 'action_index';

	echo '
</head>
<body', ($context['theme_variant'] != '') ? ' id="variant'. $context['theme_variant']. '"' : '', ' class="', implode(' ',$body_class), '">';
}

function template_body_above()
{
		global $context, $settings, $options, $scripturl, $txt, $modSettings, $user_info;

	// "Go to bottom" link, followed by "Go to top" target anchor, then skipnav, forum wrapper, then header.
	if (!empty($modSettings['topbottomEnable']))
	{
	echo '
		<a href="#index_bottom" id="go_bottom" class="base_links">', $txt['go_down'], '</a>
		<a id="index_top"></a>';
	}

	echo '
	<a href="#after_linktree" id="skip_nav">', $txt['skip_nav'], '</a>
	<div id="wrapper" ',!empty($settings['forum_width']) ? 'style="width: ' . $settings['forum_width'] . '"' : '', '>
		<div id="header">
			<div id="top_section">';

	if (empty($context['header_logo_url_html_safe']))
		echo '
				<h1 id="forum_title"><a href="', $scripturl, '">', $context['forum_name'], '</a></h1>';
	else
		echo '
				<h1 id="forum_title" class="image_banner">
					<a href="'. $scripturl. '">
						<img id="forum_banner" style="max-width: ',!empty($settings['header_logo_width']) && $settings['header_logo_width'] < 100 ? $settings['header_logo_width']. '%;"' : '100%;"', ' src="', $context['header_logo_url_html_safe'], '" alt="', $context['forum_name'], '" />
					</a>
				</h1>';
		echo '
				<div id="siteslogan">
					', empty($settings['site_slogan']) ? '<img id="smflogo" src="' . $settings['images_url'] . '/smflogo.png" alt="Simple Machines Forum" title="Simple Machines Forum" />' : '<span>'. $settings['site_slogan']. '</span>', '
					<img id="upshrink" src="', $settings['images_url'], '/upshrink.png" alt="*" title="', $txt['upshrink_description'], '" style="display: none;" />
				</div>
			</div>
			<div id="upper_section" ', empty($options['collapse_header']) ? '' : 'style="display: none;"', '>
				<div class="user">';

	// If the user is logged in, display stuff like their name, new messages, etc.
	if ($context['user']['is_logged'])
	{
		echo '
					<p class="avatar">
						<a href="', $scripturl, '?action=profile">';

		if (empty($options['show_no_avatars']) && !empty($context['user']['avatar'])) {
			echo '		', $context['user']['avatar']['image'], '</a>';
		}

		elseif ($user_info['groups']['0'] != '') {
			echo '			<span class="no_avatar group_', $user_info['groups']['0'], '">', (substr($context['user']['name'], 0, 1)), '</span></a>';
		}

		elseif ($user_info['groups']['1'] != '') {
			echo '			<span class="no_avatar group_', $user_info['groups']['1'], '">', (substr($context['user']['name'], 0, 1)), '</span></a>';
		}

		else {
			echo '			<span class="no_avatar">', (substr($context['user']['name'], 0, 1)), '</span></a>';
		}

		echo '
					</p>
					<ul class="reset">
						<li class="greeting">', $txt['hello_member_ndt'], ' ', $context['user']['name'], '</li>
						<li><a href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a></li>
						<li><a href="', $scripturl, '?action=unreadreplies">', $txt['show_unread_replies'], '</a></li>
						<li class="user_time">' ,$context['current_time'], '</li>
					</ul>';
	}
	// Otherwise they're a guest - this time ask them to either register or login.
	// NOTE: Log in form is modified to only log user in forever (value="-1").
	// The standard time increments are still available via action=login.
	elseif (!empty($context['show_login_bar']))
	{
		echo '
				<script type="text/javascript" src="', $settings['default_theme_url'], '/scripts/sha1.js"></script>
				<form id="guest_form" action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" ', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
					<label for="user">
						', $txt['username'], '
						<input type="text" id="user" name="user" size="12" class="input_text" />
					</label>
					<label for="passwrd">
						', $txt['password'], '
						<input type="password" id="passwrd" name="passwrd" size="12" class="input_password" />
					</label>
					<input type="hidden" id="cookielength" name="cookielength" value="-1" />
					<input type="submit" value="', $txt['login'], '" class="button_submit" />
					', ($modSettings['registration_method'] != 3) ? '<div class="info">'. $txt['welcome_guest']. '</div>' : '<br />';

		if (!empty($modSettings['enableOpenID']))
			echo '
					<label for="openid_url">
						', $txt['openid'], '
						<input type="text" name="openid_identifier" id="openid_url" size="19" class="input_text openid_login" />
					</label>';
echo '
					<input type="hidden" name="hash_passwrd" value="" /><input type="hidden" name="', $context['session_var'], '" value="', $context['session_id'], '" />
				</form>';
	}

		echo '
				</div>
				<div class="news">
					<form id="search_form" action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '">
						<input type="text" name="search" size="21" value="" class="input_text" />
						<input type="submit" name="submit" value="', $txt['search'], '" class="button_submit" />
						<input type="hidden" name="advanced" value="0" />';

	// Search within current topic?
	if (!empty($context['current_topic']))
		echo '
						<input type="hidden" name="topic" value="', $context['current_topic'], '" />';
	// If we're on a certain board, limit it to this board ;).
	elseif (!empty($context['current_board']))
		echo '
						<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';
		echo '
					</form>';

	// Show a random news item? (or you could pick one from news_lines...)
	if (!empty($settings['enable_news']))
	{
		echo '
					<h2>', $txt['news'], '</h2>
					<p>', $context['random_news_line'], '</p>';
	}

		echo '
				</div>
			</div>';

		// Define the upper_section toggle in JavaScript.
		echo '
			<script type="text/javascript"><!-- // --><![CDATA[
				var oMainHeaderToggle = new smc_Toggle({
					bToggleEnabled: true,
					bCurrentlyCollapsed: ', empty($options['collapse_header']) ? 'false' : 'true', ',
					aSwappableContainers: [
						\'upper_section\'
					],
					aSwapImages: [
						{
							sId: \'upshrink\',
							srcExpanded: smf_images_url + \'/upshrink.png\',
							altExpanded: ', JavaScriptEscape($txt['upshrink_description']), ',
							srcCollapsed: smf_images_url + \'/upshrink2.png\',
							altCollapsed: ', JavaScriptEscape($txt['upshrink_description']), '
						}
					],
					oThemeOptions: {
						bUseThemeSettings: ', $context['user']['is_guest'] ? 'false' : 'true', ',
						sOptionName: \'collapse_header\',
						sSessionVar: ', JavaScriptEscape($context['session_var']), ',
						sSessionId: ', JavaScriptEscape($context['session_id']), '
					},
					oCookieOptions: {
						bUseCookie: ', $context['user']['is_guest'] ? 'true' : 'false', ',
						sCookieName: \'upshrink\'
					}
				});
			// ]]></script>';

		// Show the menu here, according to the menu sub template.
		template_menu();

	echo '
		</div>';

		// The main content should go here.
	echo '
		<div id="main_content_section">';

		// Custom banners and shoutboxes should be placed here, before the linktree.

		// Show the navigation tree.
		theme_linktree();

		echo '
				<a id="after_linktree"></a>';
}

	function template_body_below()
	{
		global $context, $settings, $options, $scripturl, $txt, $modSettings;

		echo '
		</div>
	</div>';

		// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
		echo '
	<div id="footer_section">
		<div class="footer" ',!empty($settings['forum_width']) ? 'style="width: ' . $settings['forum_width'] . '"' : '', '>
			<ul class="reset">
				<li class="copyright">', theme_copyright(), '</li>
				', !empty($modSettings['xmlnews_enable']) && (!empty($modSettings['allow_guestAccess']) || $context['user']['is_logged']) ? '<li><a id="button_rss" href="' . $scripturl . '?action=.xml;type=rss" class="new_win">' . $txt['rss'] . '</a></li>' : '', '
				<li class="last"><a id="button_xhtml" href="http://validator.w3.org/check?uri=referer" target="_blank" rel="noopener" class="new_win" title="', $txt['valid_xhtml'], '">', $txt['xhtml'], '</a></li>
			</ul>';

		// Show the load time?
		if ($context['show_load_time'])
			echo '
			<p>', $txt['page_created'], $context['load_time'], $txt['seconds_with'], $context['load_queries'], $txt['queries'], '</p>';

		echo '
		</div>
	</div>';
	}

function template_html_below()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;
	
	if (!empty($modSettings['topbottomEnable']))
	{
	echo '
		<a href="#index_top" id="go_top" class="base_links">', $txt['go_up'], '</a>
		<a id="index_bottom"></a>';
	}
	
	echo '
</body>
</html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree($force_show = false)
{
	global $context, $settings, $options, $shown_linktree;

	// If linktree is empty, just return - also allow an override.
	if (empty($context['linktree']) || (!empty($context['dont_default_linktree']) && !$force_show))
		return;

	echo '
		<ul class="linktree">';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		echo '
			<li', ($link_num == count($context['linktree']) - 1) ? ' class="last"' : '', '>';

		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo $settings['linktree_link'] && isset($tree['url']) ? '
				<a href="' . $tree['url'] . '"><span>' . $tree['name'] . '</span></a>' : '<span>' . $tree['name'] . '</span>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		echo '
			</li>';
	}
	echo '
		</ul>';

	$shown_linktree = true;
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	echo '
		<input type="checkbox" id="main_menu_checkbox" class="togglebox" />
		<div id="main_menu">
			<label for="main_menu_checkbox" class="hamburger">', $txt['main_menu'], '</label>
			<ul id="menu_nav" class="dropmenu">';

	foreach ($context['menu_buttons'] as $act => $button)
	{
		echo '
				<li id="button_', $act, '">
					<a class="', $button['active_button'] ? 'active ' : '', 'firstlevel" href="', $button['href'], '"', isset($button['target']) ? ' target="' . $button['target'] . '" rel="noopener"' : '', '>
						', $button['title'], '
					</a>';
		if (!empty($button['sub_buttons']))
		{
			echo '
					<ul class="submenu">';

			foreach ($button['sub_buttons'] as $childbutton)
			{
				echo '
						<li>
							<a href="', $childbutton['href'], '"', isset($childbutton['target']) ? ' target="' . $childbutton['target'] . '" rel="noopener"' : '', '>
								', $childbutton['title'], !empty($childbutton['sub_buttons']) ? '...' : '', '
							</a>';
				// 3rd level menus :)
				if (!empty($childbutton['sub_buttons']))
				{
					echo '
							<ul class="submenu">';

					foreach ($childbutton['sub_buttons'] as $grandchildbutton)
						echo '
								<li>
									<a href="', $grandchildbutton['href'], '"', isset($grandchildbutton['target']) ? ' target="' . $grandchildbutton['target'] . '" rel="noopener"' : '', '>
										', $grandchildbutton['title'], '
									</a>
								</li>';

					echo '
							</ul>';
				}

				echo '
						</li>';
			}
				echo '
					</ul>';
		}
		echo '
				</li>';
	}

	echo '
			</ul>
		</div>';

	// If the user is logged in, display any necessary notifications.
	echo '
		<div class="secondary_menu">';

	if ($context['user']['is_logged'])
	{

	// Is the forum in maintenance mode?
	if ($context['in_maintenance'] && $context['user']['is_admin'])
		echo ' 
			<a href="', $scripturl, '?action=admin" class="notice_maintenance">
				', $txt['maintain_mode_on'], '
			</a>';

	// Are there members awaiting approval?
	if (!empty($context['unapproved_members']))
		echo '
			<a href="', $scripturl, '?action=admin;area=viewmembers;sa=browse;type=approve" class="notice_moderator">
				', $context['unapproved_members'] ==1 ? sprintf($txt['approve_member_waiting'], $context['unapproved_members']) : sprintf($txt['approve_members_waiting'], $context['unapproved_members']) ,'
			</a>';

	// Are there any moderation reports open?
	if (!empty($context['open_mod_reports']) && $context['show_open_reports'])
		echo '
			<a href="', $scripturl, '?action=moderate;area=reports" class="notice_moderator">
				', $context['open_mod_reports'] ==1 ? sprintf($txt['mod_report_waiting'], $context['open_mod_reports']) : sprintf($txt['mod_reports_waiting'], $context['open_mod_reports']) ,'
			</a>';

	// Are there oodles of unread messages?
	if ($context['allow_pm'] && $context['user']['unread_messages'] > 0)
		echo '
			<a href="', $scripturl, '?action=pm" class="notice_messages">
				', $context['user']['unread_messages'] ==1 ? sprintf($txt['ant_message_notice'], $context['user']['unread_messages']) : sprintf($txt['ant_messages_notice'], $context['user']['unread_messages']) ,'
			</a>';
	}

	echo '
		</div>';

}

// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $strip_options = array())
{
	global $settings, $context, $txt, $scripturl;

	if (!is_array($strip_options))
		$strip_options = array();

	// List the buttons in reverse order for RTL languages.
	if ($context['right_to_left'])
		$button_strip = array_reverse($button_strip, true);

	// Create the buttons...
	$buttons = array();
	foreach ($button_strip as $key => $value)
	{
		if (!isset($value['test']) || !empty($context[$value['test']]))
			$buttons[] = '
				<li><a' . (isset($value['id']) ? ' id="button_strip_' . $value['id'] . '"' : '') . ' class="button_strip_' . $key . (isset($value['active']) ? ' active' : '') . '" href="' . $value['url'] . '"' . (isset($value['custom']) ? ' ' . $value['custom'] : '') . '>' . $txt[$value['text']] . '</a></li>';
	}

	// No buttons? No button strip either.
	if (empty($buttons))
		return;

	echo '
		<ul class="buttonlist', !empty($direction) ? ' float' . $direction : '', '"', (empty($buttons) ? ' style="display: none;"' : ''), (!empty($strip_options['id']) ? ' id="' . $strip_options['id'] . '"': ''), '>',
				implode('', $buttons), '
		</ul>';
}

?>